@@ -25,6 +25,7 @@
 #include "version.h"
 #include "patchlevel.h"
 
+#include "censor.h"
 #include "check.h"
 #include "defaults.h"
 #include "dmessage.h"
@@ -42,10 +43,12 @@
 #include "playerlist.h"
 #include "parsemeta.h"
 #include "short.h"
+#include "smessage.h"
 #include "socket.h"
 #include "stats.h"
+#include "warning.h"
 
-void    initCensoring();
+#include "cowmain.h"
 
 int     takeNearest = 0;
 
@@ -142,7 +145,7 @@ char   *str;
 
   if (!server_count)
     {
-      fprintf(stderr, "No server list, cannot resolve id\n");
+      fprintf(stderr, _("No server list, cannot resolve id\n"));
       return -1;
     }
 
@@ -160,7 +163,7 @@ char   *str;
     }
   if (i == server_count)
     {
-      fprintf(stderr, "Specified server not found.\n");
+      fprintf(stderr, _("Specified server not found.\n"));
       return -1;
     }
 
@@ -549,16 +552,12 @@ int     checking = 0;				 /* whether -c specified on
 
 #ifdef META
 int     usemeta = 0;
-int     metaType;             /* which meta to use, UDP, cache, or TCP */
-                              /* can be set in xtrekrc with metaType: */
-                              /* 1 == UDP, 2 == cache, TCP, 3 = TCP, cache */
 #define DEFAULT_METATYPE 1
 
 #endif
 
 int     cowmain(char *server, int port, char *name)
 {
-  int     intrupt(fd_set * readfds);
   int     team, s_type;
 
   char   *cp;
@@ -706,24 +705,20 @@ int     cowmain(char *server, int port, char *name)
 	}
     }
 
-  newwin(display_host, name);
-
 #ifdef META
   if (usemeta)
     {
-      metaType = intDefault("metaType", DEFAULT_METATYPE);
-      /* use default metatype for illegal values */
-      if ((metaType < 1) || (metaType > 3))
-          metaType = DEFAULT_METATYPE;
-      parsemeta(metaType);
+      newwinmeta(display_host, name);
+      parsemeta();
       metawindow();
       metainput(); /* calls terminate() on quit, may fork(2) */
     }
 #endif
 
+  newwin(display_host, name);
   resetdefaults();
 
-#if defined(SOUND) && defined(HAVE_SDL)
+#if defined(SOUND) && (defined(HAVE_SDL) || defined(sgi))
     Init_Sound();
 #endif
 
@@ -839,7 +834,7 @@ int     cowmain(char *server, int port, char *name)
   /* Moved SDL sound initialization to right after readdefaults() so
    * the intro can start playing ASAP 
    */
-#if defined(SOUND) && !defined(HAVE_SDL)
+#if defined(SOUND) && !defined(HAVE_SDL) && !defined(sgi)
   Init_Sound();
 #endif
 
@@ -870,9 +865,12 @@ int     cowmain(char *server, int port, char *name)
 #endif
 
 #if defined(SOUND)
+#if defined(sgi)
+      Engine_Sound(ENG_OFF);			/* turn off engine sound */
+#else
       /* text in sound.c:soundrefresh() says engine sound is not supported
-      Abort_Sound(ENGINE_SOUND);
-      */
+      Abort_Sound(ENGINE_SOUND); */
+#endif
 #endif
 
       /* give the player the motd and find out which team he wants */
@@ -922,10 +920,10 @@ int     cowmain(char *server, int port, char *name)
 	  sendByeReq();
 
 	  fprintf(stderr, "you quit\n");
+
 #if defined(SOUND)
 	  Exit_Sound();
 #endif
-
 	  if (logFile != NULL)
 	    fclose(logFile);
 
@@ -942,7 +940,11 @@ int     cowmain(char *server, int port, char *name)
 
       {
 	char    buf[80];
-	sprintf(buf, "Welcome aboard %s!", ranks[me->p_stats.st_rank].name);
+	if (me->p_stats.st_rank < nranks) {
+	  sprintf(buf, "Welcome aboard %s!", ranks[me->p_stats.st_rank].name);
+	} else {
+	  sprintf(buf, "Welcome aboard!");
+	}
 	warning(buf);
 	W_ClearArea(messagew, 5, 5, W_Textwidth * 80, W_Textheight);
       }
@@ -958,7 +960,10 @@ int     cowmain(char *server, int port, char *name)
       W_ClearWindow(w);
       /* for (i = 0; i < NSIG; i++) { (void) SIGNAL(i, SIG_IGN); } */
 
-      me->p_status = PALIVE;			 /* Put player in game */
+      me->p_flags &= ~(PFYELLOW | PFRED | PFENG);	/* Reset flags to avoid sounds */
+      me->p_flags |= PFGREEN | PFSHIELD;		/* ... from previous alerts */
+      me->p_status = PALIVE;				/* Put player in game */
+
       PlistNoteUpdate(me->p_no);
 
       if (showStats)				 /* Default showstats are on. 
@@ -1000,10 +1005,14 @@ int     cowmain(char *server, int port, char *name)
       DisplayMessage();
 
 #ifdef SOUND
-      Play_Sound(ENTER_SHIP_SOUND);
+#if defined(sgi)
+	Engine_Sound(ENG_ON);
+#else
       /* text in sound.c:soundrefresh() says engine sound is not supported
-      Play_Sound(ENGINE_SOUND);
-      */
+      Play_Sound(ENGINE_SOUND); */
+#endif
+
+      Play_Sound(ENTER_SHIP_SOUND);
 #endif
 
 #ifdef HOCKEY_LINES
@@ -1037,7 +1046,6 @@ RETSIGTYPE
 reset_game(int _dummy)
 {
   died_from_signal = 1;
-  ANNOUNCESOCKET;
   longjmp(env, 0);
 }
 #endif
