@@ -24,22 +24,21 @@
 #define PKEY 128
 
 
-#ifdef SMALL_SCREEN
-#define GWINSIDE 400
-#define TWINSIDE 500
-#else
-#define GWINSIDE 500
-#define TWINSIDE 500				 /* Size of strategic and * * 
-						  * tactical windows */
-#endif
+#define GWINSIDE (small_screen ? 400 : 500) /* size of strategic window */
+#define TWINSIDE 500 /* size of tactical window */
 
 #define BORDER 3				 /* border width for option * 
 						  * 
 						  * * windows */
 #define PSEUDOSIZE 16
-#define CLOAK_PHASES 12          /* number of drawing phases
-                                 * in a cloak
-                                 * engage/disengage */
+/*! @brief number of drawing phases in a cloak engage and disengage
+    @details refer to udcloak() in server source, once p_cloakphases
+    reaches one less than this value, position is randomised and
+    updated slowly by server.  This value was 7 for COW 2.02 with a
+    server configured for five updates per second.  Server changed to
+    ten updates per second and broke the calculations.  Now matches
+    server value adjusted for updates per second. */
+#define CLOAK_PHASES (12 * server_ups / 10)
 #define DEFAULT_NUMRANKS 9
 
 /* These are configuration definitions */
@@ -150,6 +149,10 @@
 #define MAX(a,b)		((a) > (b) ? (a) : (b))
 #endif
 
+#ifndef MIN
+#define MIN(a,b)		((a) < (b) ? (a) : (b))
+#endif
+
 #define myPlasmaTorp(t)		(me->p_no == (t)->pt_owner)
 #define myTorp(t)		(me->p_no == (t)->t_owner)
 #define friendlyPlasmaTorp(t)	((!(me->p_team & (t)->pt_war)) || (myPlasmaTorp(t)))
