@@ -192,14 +192,10 @@ static void DrawShips(void) {
 	idbuf[1] = '\0';
 
 	for (j=players + MAXPLAYER - 1; j >= players; --j) {
-		int cloak_phases = CLOAK_PHASES * server_ups / 10;
-
-		void *sprite = S_Ship(j->p_no);
-
 		/* jmn - observer support.. tried to diplay tractors but no works */
 
 		if (j->p_flags & PFCLOAK) {
-			if (j->p_cloakphase < (cloak_phases-1)) {
+			if (j->p_cloakphase < (CLOAK_PHASES - 1)) {
 #ifdef SOUND
 				if (myPlayer(j) && (j->p_cloakphase == 0)) {
 					Play_Sound(CLOAK_SOUND);
@@ -211,7 +207,7 @@ static void DrawShips(void) {
 			if (j->p_cloakphase) {
 #ifdef SOUND
 				if (myPlayer(j)) {
-					if (j->p_cloakphase == cloak_phases - 1) {
+					if (j->p_cloakphase == CLOAK_PHASES - 1) {
 						Play_Sound(UNCLOAK_SOUND);
 					}
 # if !defined(sgi)
@@ -224,6 +220,7 @@ static void DrawShips(void) {
 				j->p_cloakphase--;
 			}
 		}
+		void *sprite = S_Ship(j->p_no);
 
 		dx = j->p_x - me->p_x;
 		dy = j->p_y - me->p_y;
@@ -235,7 +232,7 @@ static void DrawShips(void) {
 		dy = dy / SCALE + TWINSIDE / 2;
 
 		if ((sprite == NULL) || (pixFlags & NO_CLK_PIX))
-		  if (j->p_flags & PFCLOAK && (j->p_cloakphase == (cloak_phases - 1))) {
+		  if (j->p_flags & PFCLOAK && (j->p_cloakphase == (CLOAK_PHASES - 1))) {
 			if (myPlayer(j)
 #ifdef RECORDGAME
 					|| playback
@@ -351,7 +348,7 @@ static void DrawShips(void) {
 
 #ifdef BEEPLITE
 			if ((UseLite && emph_player_seq_n[j->p_no] > 0) && (liteflag & LITE_PLAYERS_LOCAL)) {
-				int seq_n = (emph_player_seq_n[j->p_no] * 10 / server_ups) % emph_player_seql_frames;
+				int seq_n = (emph_player_seq_n[j->p_no] * 5 / server_ups) % emph_player_seql_frames;
 
 				W_WriteBitmap(dx - (emph_player_seql_width / 2),
 					      dy - (emph_player_seql_height / 2),
@@ -517,7 +514,7 @@ static void DrawShips(void) {
 		      }
 
 		} else if (j->p_status == PEXPLODE) {
-			int i = j->p_explode * 10 / server_ups;
+			int i = j->p_explode * 5 / server_ups;
 #ifdef SOUND
 			if (j->p_explode == 1) {
 				if (j == me) {
@@ -715,7 +712,7 @@ static void DrawShips(void) {
 				tractee = &players[j->p_tractor];
 
 				if (tractee->p_status != PALIVE ||
-				    ((tractee->p_flags & PFCLOAK) && (tractee->p_cloakphase == (cloak_phases-1))))
+				    ((tractee->p_flags & PFCLOAK) && (tractee->p_cloakphase == (CLOAK_PHASES - 1))))
 					continue;
 
 				if (tcounter >= 2) {				/* continue tractor stuff */
@@ -848,8 +845,8 @@ static void DrawTorps(void) {
 			if (k->t_status == TEXPLODE) {
 				k->t_fuse--;
 
-				numdetframes = NUMDETFRAMES * server_ups / 10;
-				frame = k->t_fuse * 10 / server_ups;
+				numdetframes = NUMDETFRAMES * server_ups / 5;
+				frame = k->t_fuse * 5 / server_ups;
 
 				if (frame > NUMDETFRAMES - 1)
 					frame = NUMDETFRAMES - 1;
@@ -968,8 +965,8 @@ void DrawPlasmaTorps(void) {
 		if (pt->pt_status == PTEXPLODE) {
 			pt->pt_fuse--;
 
-			numdetframes = NUMDETFRAMES * server_ups / 10;
-			frame = pt->pt_fuse * 10 / server_ups;
+			numdetframes = NUMDETFRAMES * server_ups / 5;
+			frame = pt->pt_fuse * 5 / server_ups;
 
 			if (frame > NUMDETFRAMES-1)
 				frame = NUMDETFRAMES-1;
