@@ -4,15 +4,16 @@
  *
  * Routines neccessary to playback a game recording.
  */
-#include <setjmp.h>
 #include "config.h"
 
 #include INC_MACHINE_ENDIAN
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <unistd.h>
 #include <sys/types.h>
 #include <time.h>
+#include <setjmp.h>
 #include INC_SYS_TIME
 #include INC_SYS_WAIT
 #include INC_SYS_RESOURCE
@@ -23,19 +24,37 @@
 #include <pwd.h>
 #include <string.h>
 #include <ctype.h>
+#include <arpa/inet.h>
+
 #include "Wlib.h"
 #include "defs.h"
 #include "struct.h"
 #include "data.h"
 #include "packets.h"
+
 #include "version.h"
 #include "patchlevel.h"
+
+#include "censor.h"
 #include "cowapi.h"
+#include "defaults.h"
+#include "enter.h"
+#include "getship.h"
+#include "inform.h"
+#include "input.h"
+#include "lagmeter.h"
 #include "map.h"
+#include "newwin.h"
+#include "pingstats.h"
+#include "redraw.h"
+#include "socket.h"
 #include "spopt.h"
+#include "stats.h"
 #include "defs.h"
 #include "playerlist.h"
 
+#include "playback.h"
+
 #ifdef RECORDGAME
 extern int opened_info;				 /* counter for infowin *
 
@@ -79,6 +98,7 @@ int pb_index_compare(const void *a, const void *b);
 void rpb_init(void);
 void rpb_analyze(int diskpos, void *packet);
 void rpb_dorev(char *buf);
+static int readFromFile0();
 
 struct player *packetsme;
 struct player *displayme;
@@ -87,7 +107,10 @@ int
         pbmain(char *name)
 {
   int     i;
+
+#if 0 /* unused? */
   int     s_type;
+#endif
 
   char index_filename[FILENAME_MAX+1];
   char context_filename[FILENAME_MAX+1];
@@ -273,9 +296,12 @@ int
     return (i - RETURNBASE);			 /* Terminate with retcode */
 
 #if defined(SOUND)
-  /* text in sound.c:soundrefresh() says engine sound is not supported
-  Abort_Sound(ENGINE_SOUND);
-  */
+#if defined(sgi)
+	Engine_Sound(ENG_OFF);			/* Stop engine sound */
+#else
+	/* text in sound.c:soundrefresh() says engine sound is not supported
+	Abort_Sound(ENGINE_SOUND); */
+#endif
 #endif
 
 #ifdef nodef
@@ -315,10 +341,14 @@ int
     redrawPStats();
 
 #ifdef SOUND
-  Play_Sound(ENTER_SHIP_SOUND);
-  /* text in sound.c:soundrefresh() says engine sound is not supported
-  Play_Sound(ENGINE_SOUND);
-  */
+#if defined(sgi)
+	Engine_Sound(ENG_ON);
+#else
+	/* text in sound.c:soundrefresh() says engine sound is not supported
+	Play_Sound(ENGINE_SOUND);
+	*/
+#endif
+	Play_Sound(ENTER_SHIP_SOUND);
 #endif
 
 #ifdef HOCKEY_LINES
@@ -350,7 +380,7 @@ int
 	  /* W_Flush(); */
 	}
 
-      intrupt();
+      intrupt(NULL);
       W_Flush();
       if (!pb_stepping) usleep(pbdelay);
       if (pb_snapping) W_CameraSnap(w);
@@ -392,7 +422,7 @@ void
       case 'J': /* abort jump */
           jump_on = 0;
           playback = tmp_playback;
-          printf("Aborting jump.\n", jump_str);
+          printf("Aborting jump.\n");
           jump_str[0] = '\0';
           break;
       default: /* Done entering jump data when non-digit key hit. */
@@ -532,7 +562,7 @@ void
    displayme = me;
 }
 
-inline int
+int
         ckRecordPacket(char packet)
 {
   return 1;
@@ -614,7 +644,7 @@ pb_dopacket(char *buf)
 
 
   /* Determine how many more bytes we need to read. */
-  size = handlers[buf[0]].size;
+  size = handlers[(unsigned char) buf[0]].size;
   if (size == -1)
     {
       if (buf[0] == SP_S_MESSAGE)
@@ -644,7 +674,7 @@ pb_dopacket(char *buf)
     }
 
   /* Call the packet handler and return success (zero). */
-  (*(handlers[buf[0]].handler)) (buf
+  (*(handlers[(unsigned char) buf[0]].handler)) (buf
 #ifdef CORRUPTED_PACKETS
 				 ,recordFile
 #endif
@@ -703,8 +733,7 @@ int readFromFile() {
 }
 
 
-int
-readFromFile0()
+static int readFromFile0()
 {
 #define MAXPACKETSIZE 128
   static uint aligned_buf[MAXPACKETSIZE/sizeof(uint)];
@@ -714,7 +743,10 @@ readFromFile0()
   int diskpos;
   int sequence_start_pos = -1;
   int sequence_num_context = 0;
+
+#if 0 /* unused? */
   int read_context = 0;
+#endif
 
 
   if (playback == PL_PAUSE)
@@ -1212,11 +1244,13 @@ rpb_analyze(int diskpos, void *packet)
  	else if (sbuf[1] & 64)
  	  {
  	    offset = 0;
- 	    if (shortversion == SHORTVERSION)
- 	      if (sbuf[2] == 2)
- 		sbuf += 8;
- 	      else if (sbuf[2] == 1)
- 		sbuf += 4;
+            if (shortversion == SHORTVERSION) {
+              if (sbuf[2] == 2) {
+                sbuf += 8;
+              } else if (sbuf[2] == 1) {
+                sbuf += 4;
+              }
+            }
  	  }
  	else
  	  {
