@@ -362,7 +362,7 @@ void    handleVTorp(unsigned char *sbuf)
   for (shift = 0, i = 0; i < 8;
        i++, thetorp++, bitset >>= 1)
     {
-      thetorp->t_updateFuse = TORP_UPDATE_FUSE * server_ups / 10;
+      thetorp->t_updateFuse = MAX(2, TORP_UPDATE_FUSE * server_ups / 5);
 
       if (bitset & 01)
 	{
@@ -934,7 +934,7 @@ void    handleSMessage(struct mesg_s_spacket *packet)
       sprintf(addrbuf + 5, "ALL");
       break;
     case MTEAM:
-      sprintf(addrbuf + 5, teamshort[me->p_team]);
+      sprintf(addrbuf + 5, "%s", teamshort[me->p_team]);
       break;
     case MINDIV:
       /* I know that it's me -> xxx but i copied it straight ... */
@@ -1051,7 +1051,7 @@ void    handleVTorpInfo(unsigned char *sbuf)
   for (shift = 0, i = 0; i < 8;
        thetorp++, *bitset >>= 1, *infobitset >>= 1, i++)
     {
-      thetorp->t_updateFuse = TORP_UPDATE_FUSE * server_ups / 10;
+      thetorp->t_updateFuse = MAX(2, TORP_UPDATE_FUSE * server_ups / 5);
 
       if (*bitset & 01)
 	{
@@ -1149,7 +1149,7 @@ void    handleVTorpInfo(unsigned char *sbuf)
 	      thetorp->t_status = status;
 	      if (thetorp->t_status == TEXPLODE)
 		{
-		  thetorp->t_fuse = NUMDETFRAMES * server_ups / 10;
+		  thetorp->t_fuse = NUMDETFRAMES * server_ups / 5;
 		}
 	    }
 	}					 /* if */
@@ -1458,7 +1458,7 @@ void    handleSWarning(struct warning_s_spacket *packet)
       arg4 = (unsigned char) packet->argument2;
       break;
     case BEAM_U_TEXT:
-      sprintf(buf, "Transfering ground units.  (%d/%d) Starbase %s has %d armies left",
+      sprintf(buf, "Transferring ground units.  (%d/%d) Starbase %s has %d armies left",
               (unsigned char) arg3, (unsigned char) arg4,
               players[(unsigned char) packet->argument].p_name,
               (unsigned char) packet->argument2);
