@@ -443,15 +443,18 @@ void   *S_Ship(int playerno)
     }
   else if (this->p_status == PEXPLODE)
     {
-      int     i = this->p_explode * 5 / server_ups;
+      int     i;
 
       if (pixFlags & NO_EXP_PIX)
-	return ((void *) NULL);
+        return ((void *) NULL);
 
-      if (this->p_ship.s_type == STARBASE)
-	sprite = &explosionImg[1];
-      else
-	sprite = &explosionImg[0];
+      if (this->p_ship.s_type == STARBASE) {
+        i = this->p_explode * 5 / server_ups;
+        sprite = &explosionImg[1];
+      } else {
+        i = this->p_explode * 10 / server_ups;
+        sprite = &explosionImg[0];
+      }
 
       if (i >= sprite->nviews)
 	return ((void *) NULL);
@@ -475,8 +478,10 @@ void   *S_Ship(int playerno)
 	}
       else
 	{
+	  if ((CLOAK_PHASES - 2) == 0)
+	      return ((void *) NULL);
 	  sprite->cloak = this->p_cloakphase;
-	  cloakImg.view = cloakImg.nviews - this->p_cloakphase - 1;
+	  cloakImg.view = MAX(0, cloakImg.nviews - (this->p_cloakphase * (cloakImg.nviews - 1) / (CLOAK_PHASES - 2)) - 2);
 	}
     }
 
@@ -660,8 +665,8 @@ void   *S_Plasma(int plasmatorpno)
     {
       sprite = &plasmaImg[remap[players[this->pt_owner].p_team]][1];
       this->pt_fuse--;
-      numdetframes = NUMDETFRAMES * server_ups / 10;
-      frame = this->pt_fuse * 10 / server_ups;
+      numdetframes = NUMDETFRAMES * server_ups / 5;
+      frame = this->pt_fuse * 5 / server_ups;
       if (this->pt_fuse <= 0)
 	{
 	  this->pt_status = PTFREE;
